# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: a7p/profedit_validate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from a7p.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x37p/profedit_validate.proto\x12\x08profedit\x1a\x1b\x62uf/validate/validate.proto\"6\n\x07Payload\x12+\n\x07profile\x18\x01 \x01(\x0b\x32\x11.profedit.ProfileR\x07profile\".\n\x07\x43oefRow\x12\x13\n\x05\x62\x63_cd\x18\x01 \x01(\x05R\x04\x62\x63\x43\x64\x12\x0e\n\x02mv\x18\x02 \x01(\x05R\x02mv\"\xa3\x01\n\x05SwPos\x12\x13\n\x05\x63_idx\x18\x01 \x01(\x05R\x04\x63Idx\x12\x1f\n\x0breticle_idx\x18\x02 \x01(\x05R\nreticleIdx\x12\x12\n\x04zoom\x18\x03 \x01(\x05R\x04zoom\x12\x1a\n\x08\x64istance\x18\x04 \x01(\x05R\x08\x64istance\x12\x34\n\rdistance_from\x18\x05 \x01(\x0e\x32\x0f.profedit.DTypeR\x0c\x64istanceFrom\"\x97\x0b\n\x07Profile\x12*\n\x0cprofile_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\x0bprofileName\x12.\n\x0e\x63\x61rtridge_name\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\rcartridgeName\x12(\n\x0b\x62ullet_name\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\nbulletName\x12-\n\x0eshort_name_top\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x18\x08R\x0cshortNameTop\x12-\n\x0eshort_name_bot\x18\x05 \x01(\tB\x07\xbaH\x04r\x02\x18\x08R\x0cshortNameBot\x12%\n\tuser_note\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\xfa\x01R\x08userNote\x12+\n\x06zero_x\x18\x07 \x01(\x05\x42\x14\xbaH\x11\x1a\x0f\x18\xc0\xcf$(\xc0\xb0\xdb\xff\xff\xff\xff\xff\xff\x01R\x05zeroX\x12+\n\x06zero_y\x18\x08 \x01(\x05\x42\x14\xbaH\x11\x1a\x0f\x18\xc0\xcf$(\xc0\xb0\xdb\xff\xff\xff\xff\xff\xff\x01R\x05zeroY\x12\x30\n\tsc_height\x18\t \x01(\x05\x42\x13\xbaH\x10\x1a\x0e\x18\x88\'(\xf8\xd8\xff\xff\xff\xff\xff\xff\xff\x01R\x08scHeight\x12#\n\x07r_twist\x18\n \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\x90N(\x00R\x06rTwist\x12\x37\n\x11\x63_muzzle_velocity\x18\x0b \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xb0\xea\x01(dR\x0f\x63MuzzleVelocity\x12@\n\x12\x63_zero_temperature\x18\x0c \x01(\x05\x42\x12\xbaH\x0f\x1a\r\x18\x64(\x9c\xff\xff\xff\xff\xff\xff\xff\xff\x01R\x10\x63ZeroTemperature\x12&\n\tc_t_coeff\x18\r \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xb8\x17(\x02R\x07\x63TCoeff\x12\x39\n\x13\x63_zero_distance_idx\x18\x0e \x01(\x05\x42\n\xbaH\x07\x1a\x05\x10\xc8\x01(\x00R\x10\x63ZeroDistanceIdx\x12G\n\x16\x63_zero_air_temperature\x18\x0f \x01(\x05\x42\x12\xbaH\x0f\x1a\r\x18\x64(\x9c\xff\xff\xff\xff\xff\xff\xff\xff\x01R\x13\x63ZeroAirTemperature\x12-\n\x13\x63_zero_air_pressure\x18\x10 \x01(\x05R\x10\x63ZeroAirPressure\x12\x38\n\x13\x63_zero_air_humidity\x18\x11 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64(\x00R\x10\x63ZeroAirHumidity\x12\x37\n\x0e\x63_zero_w_pitch\x18\x12 \x01(\x05\x42\x12\xbaH\x0f\x1a\r\x18Z(\xa6\xff\xff\xff\xff\xff\xff\xff\xff\x01R\x0b\x63ZeroWPitch\x12\x43\n\x14\x63_zero_p_temperature\x18\x13 \x01(\x05\x42\x12\xbaH\x0f\x1a\r\x18\x64(\x9c\xff\xff\xff\xff\xff\xff\xff\xff\x01R\x11\x63ZeroPTemperature\x12*\n\nb_diameter\x18\x14 \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xff\xff\x03(\x01R\tbDiameter\x12&\n\x08\x62_weight\x18\x15 \x01(\x05\x42\x0b\xbaH\x08\x1a\x06\x18\xff\xff\x03(\nR\x07\x62Weight\x12%\n\x08\x62_length\x18\x16 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\x90N(\x01R\x07\x62Length\x12/\n\ttwist_dir\x18\x17 \x01(\x0e\x32\x12.profedit.TwistDirR\x08twistDir\x12(\n\x07\x62\x63_type\x18\x18 \x01(\x0e\x32\x0f.profedit.GTypeR\x06\x62\x63Type\x12\x37\n\x08switches\x18\x19 \x03(\x0b\x32\x0f.profedit.SwPosB\n\xbaH\x07\x92\x01\x04\x08\x01\x10\x04R\x08switches\x12)\n\tdistances\x18\x1a \x03(\x05\x42\x0b\xbaH\x08\x92\x01\x05\x08\x04\x10\xc8\x01R\tdistances\x12;\n\tcoef_rows\x18\x1b \x03(\x0b\x32\x11.profedit.CoefRowB\x0b\xbaH\x08\x92\x01\x05\x08\x01\x10\xc8\x01R\x08\x63oefRows\x12!\n\x07\x63\x61liber\x18\x1c \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\x07\x63\x61liber\x12(\n\x0b\x64\x65vice_uuid\x18\x1d \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\ndeviceUuid*\x1d\n\x05\x44Type\x12\t\n\x05VALUE\x10\x00\x12\t\n\x05INDEX\x10\x01*#\n\x05GType\x12\x06\n\x02G1\x10\x00\x12\x06\n\x02G7\x10\x01\x12\n\n\x06\x43USTOM\x10\x02*\x1f\n\x08TwistDir\x12\t\n\x05RIGHT\x10\x00\x12\x08\n\x04LEFT\x10\x01\x42\x32Z0github.com/jaremko/a7p_transfer_example/profeditb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'a7p.profedit_validate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/jaremko/a7p_transfer_example/profedit'
  _PROFILE.fields_by_name['profile_name']._options = None
  _PROFILE.fields_by_name['profile_name']._serialized_options = b'\272H\004r\002\0302'
  _PROFILE.fields_by_name['cartridge_name']._options = None
  _PROFILE.fields_by_name['cartridge_name']._serialized_options = b'\272H\004r\002\0302'
  _PROFILE.fields_by_name['bullet_name']._options = None
  _PROFILE.fields_by_name['bullet_name']._serialized_options = b'\272H\004r\002\0302'
  _PROFILE.fields_by_name['short_name_top']._options = None
  _PROFILE.fields_by_name['short_name_top']._serialized_options = b'\272H\004r\002\030\010'
  _PROFILE.fields_by_name['short_name_bot']._options = None
  _PROFILE.fields_by_name['short_name_bot']._serialized_options = b'\272H\004r\002\030\010'
  _PROFILE.fields_by_name['user_note']._options = None
  _PROFILE.fields_by_name['user_note']._serialized_options = b'\272H\005r\003\030\372\001'
  _PROFILE.fields_by_name['zero_x']._options = None
  _PROFILE.fields_by_name['zero_x']._serialized_options = b'\272H\021\032\017\030\300\317$(\300\260\333\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['zero_y']._options = None
  _PROFILE.fields_by_name['zero_y']._serialized_options = b'\272H\021\032\017\030\300\317$(\300\260\333\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['sc_height']._options = None
  _PROFILE.fields_by_name['sc_height']._serialized_options = b'\272H\020\032\016\030\210\'(\370\330\377\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['r_twist']._options = None
  _PROFILE.fields_by_name['r_twist']._serialized_options = b'\272H\007\032\005\030\220N(\000'
  _PROFILE.fields_by_name['c_muzzle_velocity']._options = None
  _PROFILE.fields_by_name['c_muzzle_velocity']._serialized_options = b'\272H\010\032\006\030\260\352\001(d'
  _PROFILE.fields_by_name['c_zero_temperature']._options = None
  _PROFILE.fields_by_name['c_zero_temperature']._serialized_options = b'\272H\017\032\r\030d(\234\377\377\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['c_t_coeff']._options = None
  _PROFILE.fields_by_name['c_t_coeff']._serialized_options = b'\272H\007\032\005\030\270\027(\002'
  _PROFILE.fields_by_name['c_zero_distance_idx']._options = None
  _PROFILE.fields_by_name['c_zero_distance_idx']._serialized_options = b'\272H\007\032\005\020\310\001(\000'
  _PROFILE.fields_by_name['c_zero_air_temperature']._options = None
  _PROFILE.fields_by_name['c_zero_air_temperature']._serialized_options = b'\272H\017\032\r\030d(\234\377\377\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['c_zero_air_humidity']._options = None
  _PROFILE.fields_by_name['c_zero_air_humidity']._serialized_options = b'\272H\006\032\004\030d(\000'
  _PROFILE.fields_by_name['c_zero_w_pitch']._options = None
  _PROFILE.fields_by_name['c_zero_w_pitch']._serialized_options = b'\272H\017\032\r\030Z(\246\377\377\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['c_zero_p_temperature']._options = None
  _PROFILE.fields_by_name['c_zero_p_temperature']._serialized_options = b'\272H\017\032\r\030d(\234\377\377\377\377\377\377\377\377\001'
  _PROFILE.fields_by_name['b_diameter']._options = None
  _PROFILE.fields_by_name['b_diameter']._serialized_options = b'\272H\010\032\006\030\377\377\003(\001'
  _PROFILE.fields_by_name['b_weight']._options = None
  _PROFILE.fields_by_name['b_weight']._serialized_options = b'\272H\010\032\006\030\377\377\003(\n'
  _PROFILE.fields_by_name['b_length']._options = None
  _PROFILE.fields_by_name['b_length']._serialized_options = b'\272H\007\032\005\030\220N(\001'
  _PROFILE.fields_by_name['switches']._options = None
  _PROFILE.fields_by_name['switches']._serialized_options = b'\272H\007\222\001\004\010\001\020\004'
  _PROFILE.fields_by_name['distances']._options = None
  _PROFILE.fields_by_name['distances']._serialized_options = b'\272H\010\222\001\005\010\004\020\310\001'
  _PROFILE.fields_by_name['coef_rows']._options = None
  _PROFILE.fields_by_name['coef_rows']._serialized_options = b'\272H\010\222\001\005\010\001\020\310\001'
  _PROFILE.fields_by_name['caliber']._options = None
  _PROFILE.fields_by_name['caliber']._serialized_options = b'\272H\004r\002\0302'
  _PROFILE.fields_by_name['device_uuid']._options = None
  _PROFILE.fields_by_name['device_uuid']._serialized_options = b'\272H\004r\002\0302'
  _globals['_DTYPE']._serialized_start=1774
  _globals['_DTYPE']._serialized_end=1803
  _globals['_GTYPE']._serialized_start=1805
  _globals['_GTYPE']._serialized_end=1840
  _globals['_TWISTDIR']._serialized_start=1842
  _globals['_TWISTDIR']._serialized_end=1873
  _globals['_PAYLOAD']._serialized_start=70
  _globals['_PAYLOAD']._serialized_end=124
  _globals['_COEFROW']._serialized_start=126
  _globals['_COEFROW']._serialized_end=172
  _globals['_SWPOS']._serialized_start=175
  _globals['_SWPOS']._serialized_end=338
  _globals['_PROFILE']._serialized_start=341
  _globals['_PROFILE']._serialized_end=1772
# @@protoc_insertion_point(module_scope)
